@@ -59,8 +59,8 @@ func newRootCmd(version goversion.Info, exit func(int)) *rootCmd {
 	}
 	cmd := &cobra.Command{
 		Use:   "goreleaser",
-		Short: "Deliver Go binaries as fast and easily as possible",
-		Long: `GoReleaser is a release automation tool for Go projects.
+		Short: "Release engineering, simplified",
+		Long: `GoReleaser is a release automation tool.
 Its goal is to simplify the build, release and publish steps while providing variant customization options for all steps.
 
 GoReleaser is built for CI tools, you only need to download and execute it in your build script. Of course, you can also install it locally if you wish.
