@@ -14,7 +14,7 @@ import (
 	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/google/go-github/v66/github"
+	"github.com/google/go-github/v67/github"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
 	"github.com/goreleaser/goreleaser/v2/pkg/config"
@@ -436,13 +436,8 @@ func (c *githubClient) PublishRelease(ctx *context.Context, releaseID string) er
 
 func (c *githubClient) createOrUpdateRelease(ctx *context.Context, data *github.RepositoryRelease, body string) (*github.RepositoryRelease, error) {
 	c.checkRateLimit(ctx)
-	release, _, err := c.client.Repositories.GetReleaseByTag(
-		ctx,
-		ctx.Config.Release.GitHub.Owner,
-		ctx.Config.Release.GitHub.Name,
-		data.GetTagName(),
-	)
-	if err != nil {
+	release, err := c.findRelease(ctx, data.GetTagName())
+	if err != nil || release == nil {
 		release, resp, err := c.client.Repositories.CreateRelease(
 			ctx,
 			ctx.Config.Release.GitHub.Owner,
@@ -474,6 +469,19 @@ func (c *githubClient) createOrUpdateRelease(ctx *context.Context, data *github.
 	return c.updateRelease(ctx, release.GetID(), data)
 }
 
+func (c *githubClient) findRelease(ctx *context.Context, name string) (*github.RepositoryRelease, error) {
+	if !ctx.Config.Release.UseExistingDraft {
+		release, _, err := c.client.Repositories.GetReleaseByTag(
+			ctx,
+			ctx.Config.Release.GitHub.Owner,
+			ctx.Config.Release.GitHub.Name,
+			name,
+		)
+		return release, err
+	}
+	return c.findDraftRelease(ctx, name)
+}
+
 func (c *githubClient) updateRelease(ctx *context.Context, id int64, data *github.RepositoryRelease) (*github.RepositoryRelease, error) {
 	c.checkRateLimit(ctx)
 	release, resp, err := c.client.Repositories.EditRelease(
@@ -658,6 +666,30 @@ func overrideGitHubClientAPI(ctx *context.Context, client *github.Client) error
 }
 
 func (c *githubClient) deleteExistingDraftRelease(ctx *context.Context, name string) error {
+	c.checkRateLimit(ctx)
+	release, err := c.findDraftRelease(ctx, name)
+	if err != nil {
+		return fmt.Errorf("could not delete existing drafts: %w", err)
+	}
+	if release != nil {
+		if _, err := c.client.Repositories.DeleteRelease(
+			ctx,
+			ctx.Config.Release.GitHub.Owner,
+			ctx.Config.Release.GitHub.Name,
+			release.GetID(),
+		); err != nil {
+			return fmt.Errorf("could not delete previous draft release: %w", err)
+		}
+
+		log.WithField("commit", release.GetTargetCommitish()).
+			WithField("tag", release.GetTagName()).
+			WithField("name", release.GetName()).
+			Info("deleted previous draft release")
+	}
+	return nil
+}
+
+func (c *githubClient) findDraftRelease(ctx *context.Context, name string) (*github.RepositoryRelease, error) {
 	c.checkRateLimit(ctx)
 	opt := github.ListOptions{PerPage: 50}
 	for {
@@ -668,30 +700,15 @@ func (c *githubClient) deleteExistingDraftRelease(ctx *context.Context, name str
 			&opt,
 		)
 		if err != nil {
-			return fmt.Errorf("could not delete existing drafts: %w", err)
+			return nil, fmt.Errorf("could not list existing drafts: %w", err)
 		}
 		for _, r := range releases {
 			if r.GetDraft() && r.GetName() == name {
-				if _, err := c.client.Repositories.DeleteRelease(
-					ctx,
-					ctx.Config.Release.GitHub.Owner,
-					ctx.Config.Release.GitHub.Name,
-					r.GetID(),
-				); err != nil {
-					return fmt.Errorf("could not delete previous draft release: %w", err)
-				}
-
-				log.WithField("commit", r.GetTargetCommitish()).
-					WithField("tag", r.GetTagName()).
-					WithField("name", r.GetName()).
-					Info("deleted previous draft release")
-
-				// in theory, there should be only 1 release matching, so we can just return
-				return nil
+				return r, nil
 			}
 		}
 		if resp.NextPage == 0 {
-			return nil
+			return nil, nil
 		}
 		opt.Page = resp.NextPage
 	}
