@@ -8,12 +8,12 @@ import (
 	"testing"
 	"time"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -127,6 +127,10 @@ func TestRunPipe(t *testing.T) {
 					Branch: "update-{{.Version}}",
 					PullRequest: config.PullRequest{
 						Enabled: true,
+						Base: config.PullRequestBase{
+							Owner: "ms",
+							Name:  "winget",
+						},
 					},
 				},
 			},
@@ -753,6 +757,7 @@ func TestRunPipe(t *testing.T) {
 			}
 
 			if tt.winget.Repository.PullRequest.Enabled {
+				require.True(t, client.SyncedFork)
 				require.True(t, client.OpenedPullRequest)
 			}
 		})
